#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lsp
version:              2.2.0.0
visibility:           public
id:                   lsp-2.2.0.0-6qQP2gkL6rf79FYuMnhEm0
key:                  lsp-2.2.0.0-6qQP2gkL6rf79FYuMnhEm0
license:              MIT
copyright:            Alan Zimmerman, 2016-2021
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman
homepage:             https://github.com/haskell/lsp
synopsis:             Haskell library for the Microsoft Language Server Protocol
description:
    An implementation of the types, and basic message server to
    allow language implementors to support the Language Server
    Protocol for their specific language.

    An example of this is for Haskell via the Haskell Language
    Server, at https://github.com/haskell/haskell-language-server

category:             Development
abi:                  6e6cf4645340d2969adc998c31a23fd1
exposed:              True
exposed-modules:
    Language.LSP.Diagnostics, Language.LSP.Logging,
    Language.LSP.Protocol.Capabilities from lsp-types-2.0.2.0-Hjm9ElnjsL6F8974kvB8CT:Language.LSP.Protocol.Capabilities,
    Language.LSP.Protocol.Lens from lsp-types-2.0.2.0-Hjm9ElnjsL6F8974kvB8CT:Language.LSP.Protocol.Lens,
    Language.LSP.Protocol.Message from lsp-types-2.0.2.0-Hjm9ElnjsL6F8974kvB8CT:Language.LSP.Protocol.Message,
    Language.LSP.Protocol.Types from lsp-types-2.0.2.0-Hjm9ElnjsL6F8974kvB8CT:Language.LSP.Protocol.Types,
    Language.LSP.Server, Language.LSP.VFS

hidden-modules:
    Language.LSP.Server.Control Language.LSP.Server.Core
    Language.LSP.Server.Processing

import-dirs:          /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp
hs-libraries:         HSlsp-2.2.0.0-6qQP2gkL6rf79FYuMnhEm0
depends:
    aeson-2.2.2.0-4XfhhWkmpwnB2gRUwfJP7g
    async-2.2.6-KNp1RIrM7Vj10YlQJqjVD7
    attoparsec-0.14.4-IK8bf7Jdhmx3QhZQbOSRoN base-4.18.2.1
    bytestring-0.11.5.3 co-log-core-0.3.2.6-JO3HPgjEzKEJ86NAvwQALV
    containers-0.6.7 data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG
    directory-1.3.8.5 exceptions-0.10.7 filepath-1.4.300.1
    hashable-1.4.7.0-DjTaTzSxyhZLemTcoX34jw
    lens-5.3.5-AYBI3DxVlEzIh1R399daMf
    lens-aeson-1.2.3-5NRQxAvwBQKCDBsNh2qX03
    lsp-types-2.0.2.0-Hjm9ElnjsL6F8974kvB8CT mtl-2.3.1
    prettyprinter-1.7.1-7gqni6JNC026grHQxT0UM8
    random-1.2.1.3-2LG4oKHozRZIBhqa0LdfCt
    row-types-1.0.1.2-17dnAW4BcyR4ZB2fxcPAF3
    sorted-list-0.2.3.1-H4IYMgqUM8HBslJjnAG78 stm-2.5.1.0
    temporary-1.3-Klgi73SzFBU6HdICepglv2 text-2.0.2
    text-rope-0.3-B6mgh5Cy1kn25St3VW4LSS transformers-0.6.1.0
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-3DXXOqLpcMZGFktSBwG2cs
    uuid-1.3.16.1-LlF2LfLnDaCEi1eJOQRoER

haddock-interfaces:   /usr/share/doc/haskell-lsp/html/lsp.haddock
haddock-html:         /usr/share/doc/haskell-lsp/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

